#include <LiquidCrystal_I2C.h>  // Library for LCD
#include <Wire.h>

#define laser1 2
#define laser2 5  // Pin for the second laser
#define sensor1 3
#define sensor2 6  // Pin for the second sensor
#define buzzer 12

int score1 = 0;
int score2 = 0;
bool score2Triggerd = false;
bool score1Triggerd = false;

float oldTime;
float currentTime;
float deltaTime;

LiquidCrystal_I2C lcd(0x27, 16, 2);

int noteIndex = 0;
float noteTimer = 125;
bool playNotes;
bool isOn;

void setup() {
  Serial.begin(9600);
  pinMode(laser1, OUTPUT);
  pinMode(sensor1, INPUT_PULLUP);  // Use internal pull-up resistor
  pinMode(laser2, OUTPUT);
  pinMode(sensor2, INPUT_PULLUP);  // Use internal pull-up resistor
  pinMode(buzzer, OUTPUT);
  digitalWrite(laser1, HIGH);
  digitalWrite(laser2, HIGH);
  lcd.init();
  lcd.backlight();
}

void PlaySound() {
  if (!playNotes) return;

  int notes[] = { 260, 360, 460, 560, 750, 750, 750 };
  noteTimer -= deltaTime;
  if (noteTimer <= 0) {
    if (!isOn) {
      tone(buzzer, notes[noteIndex / 2]);
    } else noTone(buzzer);
    isOn = !isOn;

    Serial.println(sizeof(notes));
    noteTimer = 125;
    noteIndex++;

    if (noteIndex >= 7 * 2) {
      noteIndex = 0;
      playNotes = false;  // Reset playNotes to false after playing the sound
    }
  }
}

void loop() {
  oldTime = currentTime;
  currentTime = millis();
  deltaTime = (currentTime - oldTime);
  PlaySound();

  bool value1 = digitalRead(sensor1);
  bool value2 = digitalRead(sensor2);

  if (value1 == HIGH && !score1Triggerd) {
    score1++;  // Increase score of "Speler 1"
    score1Triggerd = true;
    playNotes = true;  // Set playNotes to true for player 1
    PlaySound();
  } else if (value1 == LOW && score1Triggerd) score1Triggerd = false;

  if (value2 == HIGH && !score2Triggerd) {
    score2++;  // Increase score of "Speler 2"
    score2Triggerd = true;
    playNotes = true;  // Set playNotes to true for player 2
    PlaySound();
  } else if (value2 == LOW && score2Triggerd) score2Triggerd = false;

  // Display player scores on LCD
  lcd.setCursor(0, 0);
  lcd.print("Speler 1: ");
  lcd.print(score1);

  lcd.setCursor(0, 1);
  lcd.print("Speler 2: ");
  lcd.print(score2);
  // Delay for readability and to reduce LCD flickering
}